==> agrosyst-web-0.2-sources.jar: fr/inra/agrosyst/web/actions/AgrosystJsonResultSupport.java <==
package fr.inra.agrosyst.web.actions;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: AgrosystJsonResultSupport.java 265 2013-06-25 09:28:40Z athimel $
 * $HeadURL: https://forge.codelutin.com/svn/agrosyst/tags/agrosyst-0.2/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/AgrosystJsonResultSupport.java $
 * %%
 * Copyright (C) 2013 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import java.io.IOException;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts2.dispatcher.StrutsResultSupport;

import com.google.common.base.Charsets;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.opensymphony.xwork2.ActionInvocation;

/**
 * @author Arnaud Thimel <thimel@codelutin.com>
 */
public class AgrosystJsonResultSupport extends StrutsResultSupport {

    private static final long serialVersionUID = 4604320651695670319L;

    private static final Log log = LogFactory.getLog(AgrosystJsonResultSupport.class);

    protected static GsonBuilder gsonBuilder = new GsonBuilder();

    static {
        gsonBuilder.registerTypeAdapterFactory(HibernateProxyTypeAdapter.FACTORY);
    }

    protected Gson gson;

    public Gson getGson() {
        if (gson == null) {
            gson = gsonBuilder.create();
        }
        return gson;
    }

    @Override
    protected void doExecute(String finalLocation, ActionInvocation invocation) throws Exception {
        Object jsonData = invocation.getStack().findValue("jsonData");

        if (jsonData == null && log.isWarnEnabled()) {
            log.warn("Unable to get 'jsonData'. Please check that your getJsonData() method is public.");
        }

        String json = getGson().toJson(jsonData);

        // Find the Response in context
        HttpServletResponse servletResponse = (HttpServletResponse) invocation.getInvocationContext().get(HTTP_RESPONSE);

        servletResponse.setCharacterEncoding(Charsets.UTF_8.name());
        servletResponse.setContentType("application/json");

        try {
            ServletOutputStream outputStream = servletResponse.getOutputStream();
            byte[] jsonBytes = json.getBytes(Charsets.UTF_8); // On transforme en bytes pour assurer l'encodage
            outputStream.write(jsonBytes);
        } catch (IOException e) {
            if (log.isErrorEnabled()) {
                log.error("Unable to write JSON output into Servlet Response");
            }
        }

    }

}

==> agrosyst-web-0.4.1-sources.jar: fr/inra/agrosyst/web/actions/AgrosystJsonResultSupport.java <==
package fr.inra.agrosyst.web.actions;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: AgrosystJsonResultSupport.java 920 2013-08-12 15:12:02Z echatellier $
 * $HeadURL: https://forge.codelutin.com/svn/agrosyst/tags/agrosyst-0.4.1/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/AgrosystJsonResultSupport.java $
 * %%
 * Copyright (C) 2013 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import java.io.IOException;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts2.dispatcher.StrutsResultSupport;

import com.google.common.base.Charsets;
import com.google.gson.Gson;
import com.opensymphony.xwork2.ActionInvocation;

/**
 * @author Arnaud Thimel <thimel@codelutin.com>
 */
public class AgrosystJsonResultSupport extends StrutsResultSupport {

    private static final long serialVersionUID = 4604320651695670319L;

    private static final Log log = LogFactory.getLog(AgrosystJsonResultSupport.class);

    protected Gson gson;

    public Gson getGson() {
        if (gson == null) {
            gson = AbstractAgrosystAction.GSON_BUILDER.create();
        }
        return gson;
    }

    @Override
    protected void doExecute(String finalLocation, ActionInvocation invocation) throws Exception {
        Object jsonData = invocation.getStack().findValue("jsonData");

        if (jsonData == null && log.isWarnEnabled()) {
            log.warn("Unable to get 'jsonData'. Please check that your getJsonData() method is public.");
        }

        String json = getGson().toJson(jsonData);

        // Find the Response in context
        HttpServletResponse servletResponse = (HttpServletResponse) invocation.getInvocationContext().get(HTTP_RESPONSE);

        servletResponse.setCharacterEncoding(Charsets.UTF_8.name());
        servletResponse.setContentType("application/json");

        try {
            ServletOutputStream outputStream = servletResponse.getOutputStream();
            byte[] jsonBytes = json.getBytes(Charsets.UTF_8); // On transforme en bytes pour assurer l'encodage
            outputStream.write(jsonBytes);
        } catch (IOException e) {
            if (log.isErrorEnabled()) {
                log.error("Unable to write JSON output into Servlet Response");
            }
        }

    }

}
